dynamic_color_testing library
Classes
- DynamicColorTestingUtils
- Static methods used for testing apps with dynamic color.
- SampleColorSchemes
-
Sample
ColorSchemes to be used in tests & development. - SampleCorePalettes
-
Sample
CorePalettes to be used to mock dynamic color in tests & development.
Functions
-
generateCorePalette(
int generator(int index)) → CorePalette -
Generates a
CorePalettebased on some generator function which takes an index.